<?php

declare(strict_types=1);

namespace Drupal\notifier\Channel;

use Symfony\Component\Notifier\Channel\ChannelPolicyInterface;

final readonly class ChannelPolicy implements ChannelPolicyInterface {

  /**
   * @phpstan-param array<string, array<string>|null> $policy
   * @internal
   */
  public function __construct(
    private array $policy,
  ) {
  }

  /**
   * {@inheritdoc}
   *
   * Changes the behavior to allow not set or NULL policies.
   *
   * Instead, we disallow empty policy arrays.
   */
  public function getChannels(string $importance): array {
    // When NULL or not set, ignore:
    if (!isset($this->policy[$importance])) {
      return [];
    }

    if ($this->policy[$importance] === []) {
      throw new \InvalidArgumentException(\sprintf('Importance "%s" must not be an empty array. Use `null` or do not define.', $importance));
    }

    return $this->policy[$importance];
  }

}
